/**
 * axios封装
 */
import axios from "axios";
import { ElMessage } from "element-plus";
// import { APP_URI } from "../config/app.config";
/**
 * show error tip
 * @param mgs
 */
const showErrorMessage = mgs => {
  ElMessage({
    message: mgs,
    type: "error",
    showClose: true
  });
};

/**
 * default axios config
 */
export const defaultConfig = {
  // baseURL: APP_URI,
  timeout: 10000
};

/**
 * default params
 * @returns {}
 */
const getDefaultParams = () => { };
const getDefaultHeaders = () => { };

/**
 * axios instance
 * @type {AxiosInstance}
 */
const instance = axios.create(defaultConfig);

/**
 * axios instance interceptors
 */
instance.interceptors.request.use(
  function (config) {
    // network error
    if (navigator.onLine !== undefined && navigator.onLine === false) {
      return Promise.reject({ message: "网络未链接", code: -1 });
    }

    /**
     * merge headers
     */
    config.headers = { ...getDefaultHeaders(), ...config.headers }

    /**
     * merge params
    */
    config.params = { ...getDefaultParams(), ...config.params }

    return config;
  },
  function (error) {
    // handle error
    return Promise.reject(error);
  }
);

/**
 * axios response instance
 */
instance.interceptors.response.use(
  function (response) {
    const { data = {} } = response;
    const code = data.code ?? -1;
    if (code !== 0) {
      const msg = data.reason || "未定义错误";
      showErrorMessage(data.reason);
      return Promise.reject({ code, msg });
    }
    if (data.message) {
      ElMessage({
        message: data.reason,
        type: "info",
        showClose: true
      });
    }
    return data;
  },
  function (error) {
    if (!(error.code && error.code === -1)) error.message = "接口请求错误";
    showErrorMessage(error.message);
    return Promise.reject(error);
  }
);

// /**
//  * Get
//  * @param {*} url
//  * @param {*} params
//  */
// export const get = ({url, params, headers}) => {
//   return instance.request({
//     url,
//     method: "get",
//     params
//   });
// };

// /**
//  * Post
//  * @param {*} url
//  * @param {*} params
//  */
// export const post = ({url, data, headers}) => {
//   return instance.request({
//     url,
//     method: "post",
//     data
//   });
// };

export default instance;
